# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: radiens_dev.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'radiens_dev.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import spikesorter_pb2 as spikesorter__pb2
from . import common_pb2 as common__pb2
from . import datasource_pb2 as datasource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11radiens_dev.proto\x12\x06\x61llego\x1a\x11spikesorter.proto\x1a\x0c\x63ommon.proto\x1a\x10\x64\x61tasource.proto\"\xb8\x01\n\x18SpkSortTrainerProfileReq\x12$\n\x04\x64src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12\x10\n\x08modelUID\x18\x02 \x02(\t\x12\x0f\n\x07outPath\x18\x03 \x02(\t\x12\x0f\n\x07isBlock\x18\x04 \x02(\x08\x12\x13\n\x0bphase1Train\x18\x05 \x01(\x08\x12\x10\n\x08posScale\x18\x06 \x01(\x01\x12\x0b\n\x03\x65ps\x18\x07 \x01(\x01\x12\x0e\n\x06minPts\x18\x08 \x01(\x05\"l\n\x1cSpkSortTrainerDeleteModelReq\x12\x35\n\x07release\x18\x01 \x01(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\x12\x15\n\risDeleteNamed\x18\x02 \x01(\x08\"r\n\x14SpkSortNetworkParams\x12\x32\n\x10inputFeatureType\x18\x01 \x02(\x0e\x32\x18.allego.InputFeatureType\x12\x13\n\x0bnumFeatures\x18\x02 \x02(\x05\x12\x11\n\tlatentDim\x18\x03 \x02(\x05\"\xa8\x03\n\x1b\x44\x65\x65pClustererCreationParams\x12\x0f\n\x07\x65ncDims\x18\x01 \x03(\x05\x12\x0e\n\x06\x65ncAct\x18\x03 \x02(\t\x12\x0f\n\x07\x64\x65\x63\x44ims\x18\x04 \x03(\x05\x12\x0e\n\x06\x64\x65\x63\x41\x63t\x18\x06 \x02(\t\x12\x13\n\x0b\x64ropoutRate\x18\x07 \x01(\x01\x12\x12\n\ndropoutVal\x18\x08 \x01(\x01\x12\x11\n\tbatchNorm\x18\n \x01(\x08\x12\x19\n\x11\x62\x61tchNormMomentum\x18\x0b \x01(\x01\x12!\n\x19\x62\x61tchNormBeforeActivation\x18\x0c \x01(\x08\x12\x17\n\x0f\x62\x61tchNormLatent\x18\r \x01(\x08\x12\x1f\n\x17\x62\x61tchNormReconstruction\x18\x0e \x01(\x08\x12\x19\n\x11\x61\x63tReconstruction\x18\x0f \x01(\t\x12\x11\n\tactLatent\x18\x10 \x01(\t\x12\x10\n\x08savePath\x18\x11 \x01(\t\x12\x10\n\x08\x62\x61seName\x18\x12 \x01(\t\x12\x10\n\x08\x62\x61seSeed\x18\x13 \x01(\x03\x12\x10\n\x08projDims\x18\x14 \x03(\x05\x12\x0f\n\x07projAct\x18\x15 \x01(\t\x12\x0c\n\x04seed\x18\x16 \x01(\x03\"\xd6\x01\n\x19SpkSortModelBuilderParams\x12H\n\x1b\x64\x65\x65pClustererCreationParams\x18\x01 \x01(\x0b\x32#.allego.DeepClustererCreationParams\x12\x32\n\x10inputFeatureType\x18\x02 \x01(\x0e\x32\x18.allego.InputFeatureType\x12\x13\n\x0bnumFeatures\x18\x03 \x01(\x05\x12\x14\n\x0cwfmResampPts\x18\x04 \x01(\x05\x12\x10\n\x08modelUID\x18\x05 \x01(\t\"\xab\x03\n\x17SpkSortModelTrainParams\x12\x33\n\tdsetTrain\x18\x01 \x02(\x0b\x32 .allego.DataSourceSetSaveRequest\x12&\n\ntrainPhase\x18\x02 \x02(\x0e\x32\x12.allego.TrainPhase\x12\x11\n\tnumEpochs\x18\x03 \x02(\x05\x12\x15\n\rminibatchSize\x18\x04 \x02(\x05\x12\x11\n\tbaseAlpha\x18\x05 \x02(\x01\x12\x16\n\x0e\x61lphaDecayRate\x18\x06 \x02(\x01\x12\x16\n\x0e\x61lphaDecayStep\x18\x07 \x02(\x05\x12\x11\n\tlossRecon\x18\x08 \x01(\x08\x12\x11\n\tlossClass\x18\t \x01(\x08\x12\x11\n\tlossClust\x18\n \x01(\x08\x12\n\n\x02l1\x18\x0c \x01(\x01\x12\n\n\x02l2\x18\r \x01(\x01\x12\x0f\n\x07numLogs\x18\x0e \x01(\x05\x12\x13\n\x0bisSaveModel\x18\x0f \x01(\x08\x12\x13\n\x0btemperature\x18\x11 \x01(\x01\x12\x13\n\x0b\x62rainRegion\x18\x12 \x01(\t\x12\x0f\n\x07probeID\x18\x13 \x01(\t\x12\x14\n\x0cnumGtNeurons\x18\x14 \x01(\x05\"\x9a\x02\n\x14SpkSortTrainerNewReq\x12=\n\x12paramsModelBuilder\x18\x01 \x02(\x0b\x32!.allego.SpkSortModelBuilderParams\x12:\n\x11paramsTrainPhase1\x18\x02 \x01(\x0b\x32\x1f.allego.SpkSortModelTrainParams\x12:\n\x11paramsTrainPhase2\x18\x03 \x01(\x0b\x32\x1f.allego.SpkSortModelTrainParams\x12:\n\x11paramsTrainPhase3\x18\x04 \x01(\x0b\x32\x1f.allego.SpkSortModelTrainParams\x12\x0f\n\x07isBlock\x18\x05 \x01(\x08\"\x8b\x01\n\x1aSpkSortLearnHyperParamsReq\x12\x10\n\x08modelUID\x18\x01 \x02(\t\x12\x0f\n\x07isBlock\x18\x02 \x02(\x08\x12\x12\n\nisPosScale\x18\x03 \x02(\x08\x12\x10\n\x08isDBScan\x18\x04 \x02(\x08\x12$\n\x04\x64src\x18\x05 \x02(\x0b\x32\x16.allego.FileDescriptor\"\xc7\x02\n\x1aSpkSortTrainerDatasetParam\x12\x13\n\x0bniPathTrain\x18\x01 \x02(\t\x12\x17\n\x0fniBaseNameTrain\x18\x02 \x02(\t\x12\x0f\n\x07NbhdDim\x18\x07 \x02(\x05\x12\x10\n\x08radiusUm\x18\x08 \x02(\x01\x12\x19\n\x11maxNumSamplesTest\x18\t \x02(\x03\x12\x1a\n\x12networkMaskingFrac\x18\n \x02(\x01\x12 \n\x18networkInitWeightsStdDev\x18\x0b \x02(\x01\x12\x1d\n\x15networkInitBiasStdDev\x18\x0c \x02(\x01\x12\x17\n\x0fnetworkL1lambda\x18\r \x02(\x01\x12*\n\"networkHiddenLayerShapeRelInputDim\x18\x0e \x03(\x01\x12\x1b\n\x13networkNumFeatures2\x18\x0f \x02(\x05\"\xbd\x01\n#SpkSortTrainerNetworkTrainingParams\x12\x11\n\tnumEpochs\x18\x01 \x02(\x05\x12\x15\n\rminibatchSize\x18\x02 \x02(\x05\x12\x15\n\rmaxNumSamples\x18\x03 \x02(\x03\x12\r\n\x05\x61lpha\x18\x04 \x02(\x01\x12\x11\n\talphaBias\x18\x05 \x02(\x01\x12\x18\n\x10\x65rrorTolPretrain\x18\x06 \x02(\x01\x12\x19\n\x11numSamplesTestMSE\x18\x07 \x02(\x05\"\x82\x02\n\x1dSpkSortTrainerStoreDescriptor\x12\x13\n\x0b\x62rainRegion\x18\x01 \x02(\t\x12\x36\n\x0bnetworkSize\x18\x02 \x02(\x0e\x32!.allego.SpkSortTrainerNetworkSize\x12\x39\n\nnbrPattern\x18\x03 \x02(\x0e\x32%.allego.SpkSortTrainerNeighborPattern\x12\x11\n\tnetworkID\x18\x04 \x02(\t\x12\x0f\n\x07NbhdDim\x18\x05 \x02(\x05\x12\x35\n\x07release\x18\x06 \x02(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\"(\n\x18SpkSortTrainerSetModeReq\x12\x0c\n\x04mode\x18\x01 \x02(\x05\"\x81\x01\n\x14SpkSortTrainerCmdReq\x12;\n\x03\x63md\x18\x01 \x02(\x0e\x32..allego.SpkSortTrainerCmdReq.SpkSortTrainerCmd\",\n\x11SpkSortTrainerCmd\x12\n\n\x06\x43MD_ON\x10\x00\x12\x0b\n\x07\x43MD_OFF\x10\x01\",\n\x19SpkSortTrainerStatusReply\x12\x0f\n\x07msgJson\x18\x01 \x02(\x0c\"W\n\x0eWrangleRequest\x12!\n\x04mode\x18\x01 \x02(\x0e\x32\x13.allego.WrangleMode\x12\"\n\x04spec\x18\x02 \x02(\x0b\x32\x14.allego.WrangleMerge\"Y\n\x0bWrangleSpec\x12%\n\x06import\x18\x01 \x03(\x0b\x32\x15.allego.WrangleImport\x12#\n\x05merge\x18\x02 \x03(\x0b\x32\x14.allego.WrangleMerge\"H\n\rWrangleImport\x12\x37\n\x0cvexSpikesSim\x18\x01 \x01(\x0b\x32!.allego.WrangleImportVexSpikesSim\"g\n\x19WrangleImportVexSpikesSim\x12\'\n\x06source\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x13\n\x0bisOverwrite\x18\x02 \x01(\x08\x12\x0c\n\x04note\x18\x03 \x01(\t\"C\n\x0fWrangleFileDesc\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12\x10\n\x08\x66ileType\x18\x03 \x01(\t\"H\n\x0cWrangleMerge\x12\x38\n\rvexSpikesView\x18\x01 \x01(\x0b\x32!.allego.WrangleMergeVexSpikesView\"\xaf\x02\n\x19WrangleMergeVexSpikesView\x12*\n\tsourceVex\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12*\n\tsourceBio\x18\x02 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x33\n\x04view\x18\x03 \x03(\x0b\x32%.allego.WrangleMergeVexSpikesViewSpec\x12\x0c\n\x04note\x18\x04 \x01(\t\x12\x18\n\x10isBandpassFilter\x18\x05 \x01(\x08\x12\x1a\n\x12\x62\x61ndpassFilterSpec\x18\x06 \x03(\x01\x12\x13\n\x0bisOverwrite\x18\x07 \x01(\x08\x12\x15\n\rspikeWindowMs\x18\x08 \x03(\x01\x12\x15\n\rspikeShadowMs\x18\t \x01(\x01\"\xc0\x01\n\x1dWrangleMergeVexSpikesViewSpec\x12(\n\x07sinkBio\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x1c\n\x14siteNeighborRadiusUm\x18\x02 \x01(\x01\x12\x1b\n\x13reqNumSiteNeighbors\x18\x03 \x01(\x05\x12\x15\n\rspikeWindowMs\x18\x04 \x03(\x01\x12\x15\n\rspikeShadowMs\x18\x05 \x01(\x01\x12\x0c\n\x04note\x18\x06 \x01(\t\"\x7f\n\x0cRecgenImport\x12\x11\n\tfilePaths\x18\x02 \x03(\t\x12\x10\n\x08outPaths\x18\x03 \x03(\t\x12\x14\n\x0cisImportXdat\x18\x04 \x01(\x08\x12\x16\n\x0eisImportSpikes\x18\x05 \x01(\x08\x12\x1c\n\x14scrapeNeighborhoodUm\x18\x06 \x01(\x01*X\n\nTrainPhase\x12\x11\n\rTRAIN_PHASE_0\x10\x00\x12\x11\n\rTRAIN_PHASE_1\x10\x01\x12\x11\n\rTRAIN_PHASE_2\x10\x02\x12\x11\n\rTRAIN_PHASE_3\x10\x03*N\n\x08LossType\x12\x11\n\rLOSS_TYPE_MSE\x10\x00\x12\x12\n\x0eLOSS_TYPE_WMSE\x10\x01\x12\x1b\n\x17LOSS_TYPE_CROSS_ENTROPY\x10\x02*\x81\x01\n\x19SpkSortTrainerNetworkSize\x12\x14\n\x10SST_SIZE_DEFAULT\x10\x00\x12\x10\n\x0cSST_SIZE_ARB\x10\x01\x12\x12\n\x0eSST_SIZE_SMALL\x10\x02\x12\x14\n\x10SST_SIZE_NOMINAL\x10\x03\x12\x12\n\x0eSST_SIZE_LARGE\x10\x04*\xa1\x01\n\x1dSpkSortTrainerNeighborPattern\x12\x17\n\x13SST_PATTERN_DEFAULT\x10\x00\x12\x13\n\x0fSST_PATTERN_ARB\x10\x01\x12\x14\n\x10SST_PATTERN_DIST\x10\x02\x12\x1d\n\x19SST_PATTERN_SPATIAL_TIGHT\x10\x03\x12\x1d\n\x19SST_PATTERN_SPATIAL_LOOSE\x10\x04*\xe3\x01\n\x1cSpkSortTrainerNetworkRelease\x12\x17\n\x13SST_NET_RELEASE_ANY\x10\x00\x12\x17\n\x13SST_NET_RELEASE_DEV\x10\x01\x12\x1b\n\x17SST_NET_RELEASE_DEV_MOD\x10\x02\x12\x18\n\x14SST_NET_RELEASE_PROD\x10\x03\x12\x1c\n\x18SST_NET_RELEASE_PROD_MOD\x10\x04\x12\x1b\n\x17SST_NET_RELEASE_SANDBOX\x10\x05\x12\x1f\n\x1bSST_NET_RELEASE_SANDBOX_MOD\x10\x06*\x83\x01\n\x0bWrangleMode\x12*\n&WRANGLE_MODE_IMPORT_NNX_VEX_SPIKES_SIM\x10\x00\x12\x1f\n\x1bWRANGLE_MODE_MERGE_FIT_VIEW\x10\x01\x12\'\n#WRANGLE_MODE_IMPORT_KILOSORT_SPIKES\x10\x02\x42\x15Z\x13internal/radix/grpc')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'radiens_dev_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\023internal/radix/grpc'
  _globals['_TRAINPHASE']._serialized_start=4129
  _globals['_TRAINPHASE']._serialized_end=4217
  _globals['_LOSSTYPE']._serialized_start=4219
  _globals['_LOSSTYPE']._serialized_end=4297
  _globals['_SPKSORTTRAINERNETWORKSIZE']._serialized_start=4300
  _globals['_SPKSORTTRAINERNETWORKSIZE']._serialized_end=4429
  _globals['_SPKSORTTRAINERNEIGHBORPATTERN']._serialized_start=4432
  _globals['_SPKSORTTRAINERNEIGHBORPATTERN']._serialized_end=4593
  _globals['_SPKSORTTRAINERNETWORKRELEASE']._serialized_start=4596
  _globals['_SPKSORTTRAINERNETWORKRELEASE']._serialized_end=4823
  _globals['_WRANGLEMODE']._serialized_start=4826
  _globals['_WRANGLEMODE']._serialized_end=4957
  _globals['_SPKSORTTRAINERPROFILEREQ']._serialized_start=81
  _globals['_SPKSORTTRAINERPROFILEREQ']._serialized_end=265
  _globals['_SPKSORTTRAINERDELETEMODELREQ']._serialized_start=267
  _globals['_SPKSORTTRAINERDELETEMODELREQ']._serialized_end=375
  _globals['_SPKSORTNETWORKPARAMS']._serialized_start=377
  _globals['_SPKSORTNETWORKPARAMS']._serialized_end=491
  _globals['_DEEPCLUSTERERCREATIONPARAMS']._serialized_start=494
  _globals['_DEEPCLUSTERERCREATIONPARAMS']._serialized_end=918
  _globals['_SPKSORTMODELBUILDERPARAMS']._serialized_start=921
  _globals['_SPKSORTMODELBUILDERPARAMS']._serialized_end=1135
  _globals['_SPKSORTMODELTRAINPARAMS']._serialized_start=1138
  _globals['_SPKSORTMODELTRAINPARAMS']._serialized_end=1565
  _globals['_SPKSORTTRAINERNEWREQ']._serialized_start=1568
  _globals['_SPKSORTTRAINERNEWREQ']._serialized_end=1850
  _globals['_SPKSORTLEARNHYPERPARAMSREQ']._serialized_start=1853
  _globals['_SPKSORTLEARNHYPERPARAMSREQ']._serialized_end=1992
  _globals['_SPKSORTTRAINERDATASETPARAM']._serialized_start=1995
  _globals['_SPKSORTTRAINERDATASETPARAM']._serialized_end=2322
  _globals['_SPKSORTTRAINERNETWORKTRAININGPARAMS']._serialized_start=2325
  _globals['_SPKSORTTRAINERNETWORKTRAININGPARAMS']._serialized_end=2514
  _globals['_SPKSORTTRAINERSTOREDESCRIPTOR']._serialized_start=2517
  _globals['_SPKSORTTRAINERSTOREDESCRIPTOR']._serialized_end=2775
  _globals['_SPKSORTTRAINERSETMODEREQ']._serialized_start=2777
  _globals['_SPKSORTTRAINERSETMODEREQ']._serialized_end=2817
  _globals['_SPKSORTTRAINERCMDREQ']._serialized_start=2820
  _globals['_SPKSORTTRAINERCMDREQ']._serialized_end=2949
  _globals['_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD']._serialized_start=2905
  _globals['_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD']._serialized_end=2949
  _globals['_SPKSORTTRAINERSTATUSREPLY']._serialized_start=2951
  _globals['_SPKSORTTRAINERSTATUSREPLY']._serialized_end=2995
  _globals['_WRANGLEREQUEST']._serialized_start=2997
  _globals['_WRANGLEREQUEST']._serialized_end=3084
  _globals['_WRANGLESPEC']._serialized_start=3086
  _globals['_WRANGLESPEC']._serialized_end=3175
  _globals['_WRANGLEIMPORT']._serialized_start=3177
  _globals['_WRANGLEIMPORT']._serialized_end=3249
  _globals['_WRANGLEIMPORTVEXSPIKESSIM']._serialized_start=3251
  _globals['_WRANGLEIMPORTVEXSPIKESSIM']._serialized_end=3354
  _globals['_WRANGLEFILEDESC']._serialized_start=3356
  _globals['_WRANGLEFILEDESC']._serialized_end=3423
  _globals['_WRANGLEMERGE']._serialized_start=3425
  _globals['_WRANGLEMERGE']._serialized_end=3497
  _globals['_WRANGLEMERGEVEXSPIKESVIEW']._serialized_start=3500
  _globals['_WRANGLEMERGEVEXSPIKESVIEW']._serialized_end=3803
  _globals['_WRANGLEMERGEVEXSPIKESVIEWSPEC']._serialized_start=3806
  _globals['_WRANGLEMERGEVEXSPIKESVIEWSPEC']._serialized_end=3998
  _globals['_RECGENIMPORT']._serialized_start=4000
  _globals['_RECGENIMPORT']._serialized_end=4127
# @@protoc_insertion_point(module_scope)
