# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pybridge.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'pybridge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import biointerface_pb2 as biointerface__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0epybridge.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x12\x62iointerface.proto\"\x17\n\x07Request\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x15\n\x05Reply\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\".\n\x1bPyBridgeFileStandardRequest\x12\x0f\n\x07\x66ileUID\x18\x01 \x02(\t\"\x92\x01\n\x17PyBridgeFileOpenRequest\x12\x0f\n\x07\x66ileUID\x18\x01 \x02(\t\x12(\n\x08\x66ileType\x18\x02 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12*\n\x06ioMode\x18\x03 \x02(\x0e\x32\x1a.allego.PyBridgeFileIOmode\x12\x10\n\x08\x66ileName\x18\x04 \x02(\t\"\x92\x01\n\x1ePyBridgeIirFilterDesignRequest\x12!\n\x08\x66iltType\x18\x01 \x02(\x0e\x32\x0f.allego.DSPType\x12\x10\n\x08\x66reqSpec\x18\x02 \x03(\x01\x12\r\n\x05order\x18\x03 \x02(\x05\x12\x10\n\x08sampFreq\x18\x04 \x02(\x01\x12\x1a\n\x12secondOrderSection\x18\x05 \x01(\x08\"6\n\x1cPyBridgeIirFilterDesignReply\x12\n\n\x02ha\x18\x01 \x03(\x01\x12\n\n\x02hb\x18\x02 \x03(\x01\"\x9e\x02\n\x14PyBridgeGetSpecReply\x12\x0f\n\x07\x66ileUID\x18\x01 \x02(\t\x12\x14\n\x0c\x64\x61taFileName\x18\x02 \x01(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x10\n\x08shapePri\x18\x04 \x03(\x03\x12\x10\n\x08shapeAux\x18\x05 \x03(\x03\x12\x10\n\x08shapeDin\x18\x06 \x03(\x03\x12\x11\n\tshapeDout\x18\x07 \x03(\x03\x12\x10\n\x08sampFreq\x18\x08 \x02(\x01\x12*\n\x08timeSpec\x18\t \x02(\x0b\x32\x18.allego.PyBridgeTimeSpec\x12.\n\x08metaData\x18\n \x01(\x0b\x32\x1c.allego.PyBridgeFileMetaData\"\xd8\x03\n\x10PyBridgeTimeSpec\x12>\n\ttimeRange\x18\x01 \x01(\x0b\x32+.allego.PyBridgeTimeSpec.PyBridgeTimeRangeT\x12H\n\x0etimestampRange\x18\x02 \x01(\x0b\x32\x30.allego.PyBridgeTimeSpec.PyBridgeTimestampRangeT\x12\x43\n\tdataBlock\x18\x03 \x01(\x0b\x32\x30.allego.PyBridgeTimeSpec.PyBridgeDataBlockRangeT\x1a\'\n\x12PyBridgeTimeRangeT\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x1a\x31\n\x17PyBridgeTimestampRangeT\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\x1a\x98\x01\n\x17PyBridgeDataBlockRangeT\x12\x15\n\rnumDataBlocks\x18\x01 \x02(\x03\x12\x1e\n\x16numSamplesPerDataBlock\x18\x02 \x02(\x03\x12\x16\n\x0e\x66irstTimestamp\x18\x03 \x02(\x03\x12\x13\n\x0bheaderBytes\x18\x04 \x02(\x03\x12\x19\n\x11numBytesDataBlock\x18\x05 \x02(\x03\"\xad\x03\n\x0fPyBridgePortMap\x12\x0f\n\x07probeID\x18\x01 \x01(\t\x12\x13\n\x0bheadstageID\x18\x02 \x01(\t\x12\x15\n\rDfDeviceLabel\x18\x03 \x01(\t\x12I\n\x11portIdxToDfSigMap\x18\x04 \x03(\x0b\x32..allego.PyBridgePortMap.PortIdxToDfSigMapEntry\x12O\n\x14\x64\x66\x43hanIdxToDfSitePos\x18\x05 \x03(\x0b\x32\x31.allego.PyBridgePortMap.DfChanIdxToDfSitePosEntry\x1a!\n\x0fPyBridgeSitePos\x12\x0e\n\x06posXYZ\x18\x01 \x03(\x01\x1a\x38\n\x16PortIdxToDfSigMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x64\n\x19\x44\x66\x43hanIdxToDfSitePosEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.allego.PyBridgePortMap.PyBridgeSitePos:\x02\x38\x01\"\xa9\x04\n\x14PyBridgeFileMetaData\x12<\n\x08portDesc\x18\x04 \x01(\x0b\x32*.allego.PyBridgeFileMetaData.PyBridgePorts\x12\x35\n\x03rhd\x18\x05 \x01(\x0b\x32(.allego.PyBridgeFileMetaData.MetadataRhd\x12(\n\x08\x61nnotate\x18\x06 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x15\n\rstartTimeUnix\x18\t \x01(\x03\x1a\xa2\x01\n\rPyBridgePorts\x12H\n\x07portMap\x18\x01 \x03(\x0b\x32\x37.allego.PyBridgeFileMetaData.PyBridgePorts.PortMapEntry\x1aG\n\x0cPortMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.allego.PyBridgePortMap:\x02\x38\x01\x1a\xb5\x01\n\x0bMetadataRhd\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x02 \x01(\t\x12\x10\n\x08portSigs\x18\x03 \x03(\x05\x12\x17\n\x0fisFilterEnabled\x18\x04 \x01(\x08\x12\x12\n\ncutoffFreq\x18\x05 \x01(\x01\x12\x16\n\x0elowerBandwidth\x18\x06 \x01(\x01\x12\x16\n\x0eupperBandwidth\x18\x07 \x01(\x01\x12\x17\n\x0fnotchFilterFreq\x18\x08 \x01(\x01\"0\n\x16PyBridgeGetStatusReply\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\"m\n\x19PyBridgeGetSignalsRequest\x12\x0e\n\x06\x66ileID\x18\x01 \x02(\t\x12\x16\n\x0etimestampRange\x18\x02 \x03(\x03\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\"\xe7\x01\n\x17PyBridgeGetSignalsReply\x12\x0e\n\x06\x66ileID\x18\x01 \x02(\t\x12\x16\n\x0etimestampRange\x18\x02 \x03(\x03\x12\x12\n\nsigDataPri\x18\x03 \x02(\x0c\x12\x13\n\x0bsigShapePri\x18\x04 \x03(\x03\x12\x12\n\nsigDataAux\x18\x05 \x02(\x0c\x12\x13\n\x0bsigShapeAux\x18\x06 \x03(\x03\x12\x12\n\nsigDataDin\x18\x07 \x02(\x0c\x12\x13\n\x0bsigShapeDin\x18\x08 \x03(\x03\x12\x13\n\x0bsigDataDout\x18\t \x02(\x0c\x12\x14\n\x0csigShapeDout\x18\n \x03(\x03\"-\n\x13MearecSignalRequest\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\"0\n\x11MearecSignalReply\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\",\n\x15MearecTemplateRequest\x12\x13\n\x0btemplateIdx\x18\x01 \x02(\x05\"-\n\x15MearecWaveformRequest\x12\x14\n\x0ctimeRangeSec\x18\x01 \x03(\x01\"\xb8\x02\n\x15SpikesPushToExportReq\x12\x17\n\x0fpathAndFileName\x18\x01 \x02(\t\x12(\n\x08\x66ileType\x18\x02 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12*\n\x04mode\x18\x03 \x02(\x0e\x32\x1c.allego.SpikesExportFileMode\x12.\n\x08metadata\x18\x04 \x01(\x0b\x32\x1c.allego.SpikesExportMetadata\x12!\n\x06sigMap\x18\x05 \x01(\x0b\x32\x11.allego.SignalMap\x12)\n\tspkMtxSet\x18\x06 \x01(\x0b\x32\x16.allego.SpikeMatrixSet\x12\x32\n\x0cneuSpkMtxSet\x18\x07 \x01(\x0b\x32\x1c.allego.NeuronSpikeMatrixSet\"\xa0\x01\n\x14SpikesExportMetadata\x12\x11\n\tnumSpikes\x18\x01 \x02(\x03\x12\x10\n\x08numSites\x18\x02 \x02(\x03\x12\x12\n\nnumNeurons\x18\x03 \x02(\x03\x12\x12\n\ndatasetUID\x18\x04 \x02(\t\x12\x10\n\x08sampFreq\x18\x05 \x02(\x01\x12\x11\n\ttimeRange\x18\x06 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x07 \x03(\x03\"I\n\x1bMearecWaveformStreamRequest\x12*\n\x0cwaveformType\x18\x02 \x02(\x0e\x32\x14.allego.WaveformType\"\x8e\x02\n\x0eMearecFileMeta\x12\x15\n\rprobeBaseName\x18\x01 \x02(\t\x12\x14\n\x0chstgBaseName\x18\x02 \x02(\t\x12\x0c\n\x04path\x18\x03 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x04 \x02(\t\x12\x14\n\x0cnumTemplates\x18\x05 \x02(\x05\x12\x15\n\rwaveformShape\x18\x06 \x03(\x05\x12\x15\n\rtemplateShape\x18\x07 \x03(\x05\x12\x10\n\x08sampFreq\x18\x08 \x02(\x01\x12\x18\n\x10templateSampFreq\x18\t \x02(\x01\x12\n\n\x02TR\x18\n \x03(\x01\x12\x0f\n\x07hstgDir\x18\x0b \x01(\t\x12\x10\n\x08probeDir\x18\x0c \x01(\t\x12\x10\n\x08wallTime\x18\r \x01(\x03\"e\n\x13MearecWaveformChunk\x12\x10\n\x08\x63hunkIdx\x18\x01 \x02(\x03\x12)\n\twaveforms\x18\x02 \x03(\x0b\x32\x16.allego.MearecWaveform\x12\x11\n\tlastChunk\x18\x03 \x01(\x08\"G\n\x0eMearecTemplate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\x13\n\x0btemplateIdx\x18\x02 \x02(\x05\x12\x12\n\npeakNtvIdx\x18\x03 \x02(\x05\"Z\n\x0eMearecWaveform\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\x11\n\tspikeTime\x18\x02 \x02(\x01\x12\x13\n\x0btemplateIdx\x18\x03 \x02(\x05\x12\x12\n\npeakNtvIdx\x18\x04 \x02(\x05*)\n\x12PyBridgeFileIOmode\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01*`\n\x14SpikesExportFileMode\x12\x16\n\x12SPIKES_FILE_CREATE\x10\x00\x12\x16\n\x12SPIKES_FILE_APPEND\x10\x01\x12\x18\n\x14SPIKES_FILE_POST_HOC\x10\x02*\'\n\x0cWaveformType\x12\t\n\x05SPIKE\x10\x00\x12\x0c\n\x08TEMPLATE\x10\x01\x32\x9f\n\n\x08PyBridge\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x39\n\x05\x43lose\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x61\n\x0fIirFilterDesign\x12&.allego.PyBridgeIirFilterDesignRequest\x1a$.allego.PyBridgeIirFilterDesignReply\"\x00\x12\x44\n\x08\x46ileOpen\x12\x1f.allego.PyBridgeFileOpenRequest\x1a\x15.allego.StandardReply\"\x00\x12V\n\rFileGetStatus\x12#.allego.PyBridgeFileStandardRequest\x1a\x1e.allego.PyBridgeGetStatusReply\"\x00\x12R\n\x0b\x46ileGetSpec\x12#.allego.PyBridgeFileStandardRequest\x1a\x1c.allego.PyBridgeGetSpecReply\"\x00\x12V\n\x0e\x46ileGetSignals\x12!.allego.PyBridgeGetSignalsRequest\x1a\x1f.allego.PyBridgeGetSignalsReply\"\x00\x12P\n\x16SpikesPushToExportFile\x12\x1d.allego.SpikesPushToExportReq\x1a\x15.allego.StandardReply\"\x00\x12Q\n\x14LoadMearecOnPybridge\x12\x1f.allego.PyBridgeFileOpenRequest\x1a\x16.allego.MearecFileMeta\"\x00\x12\\\n\x14SpikesSendMearecHDF5\x12#.allego.MearecWaveformStreamRequest\x1a\x1b.allego.MearecWaveformChunk\"\x00\x30\x01\x12I\n\x15SpikesCloseMearecHDF5\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x11GetMearecTemplate\x12\x1d.allego.MearecTemplateRequest\x1a\x16.allego.MearecTemplate\"\x00\x12R\n\x12GetMearecWaveforms\x12\x1d.allego.MearecWaveformRequest\x1a\x1b.allego.MearecWaveformChunk\"\x00\x12L\n\x10GetMearecSignals\x12\x1b.allego.MearecSignalRequest\x1a\x19.allego.MearecSignalReply\"\x00\x12\x36\n\x10StreamingRequest\x12\x0f.allego.Request\x1a\r.allego.Reply\"\x00(\x01\x12\x34\n\x0eStreamingReply\x12\x0f.allego.Request\x1a\r.allego.Reply\"\x00\x30\x01\x12>\n\x16StreamingBidirectional\x12\x0f.allego.Request\x1a\r.allego.Reply\"\x00(\x01\x30\x01\x42\x15Z\x13internal/radix/grpc')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pybridge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\023internal/radix/grpc'
  _globals['_PYBRIDGEPORTMAP_PORTIDXTODFSIGMAPENTRY']._loaded_options = None
  _globals['_PYBRIDGEPORTMAP_PORTIDXTODFSIGMAPENTRY']._serialized_options = b'8\001'
  _globals['_PYBRIDGEPORTMAP_DFCHANIDXTODFSITEPOSENTRY']._loaded_options = None
  _globals['_PYBRIDGEPORTMAP_DFCHANIDXTODFSITEPOSENTRY']._serialized_options = b'8\001'
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS_PORTMAPENTRY']._loaded_options = None
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS_PORTMAPENTRY']._serialized_options = b'8\001'
  _globals['_PYBRIDGEFILEIOMODE']._serialized_start=3941
  _globals['_PYBRIDGEFILEIOMODE']._serialized_end=3982
  _globals['_SPIKESEXPORTFILEMODE']._serialized_start=3984
  _globals['_SPIKESEXPORTFILEMODE']._serialized_end=4080
  _globals['_WAVEFORMTYPE']._serialized_start=4082
  _globals['_WAVEFORMTYPE']._serialized_end=4121
  _globals['_REQUEST']._serialized_start=60
  _globals['_REQUEST']._serialized_end=83
  _globals['_REPLY']._serialized_start=85
  _globals['_REPLY']._serialized_end=106
  _globals['_PYBRIDGEFILESTANDARDREQUEST']._serialized_start=108
  _globals['_PYBRIDGEFILESTANDARDREQUEST']._serialized_end=154
  _globals['_PYBRIDGEFILEOPENREQUEST']._serialized_start=157
  _globals['_PYBRIDGEFILEOPENREQUEST']._serialized_end=303
  _globals['_PYBRIDGEIIRFILTERDESIGNREQUEST']._serialized_start=306
  _globals['_PYBRIDGEIIRFILTERDESIGNREQUEST']._serialized_end=452
  _globals['_PYBRIDGEIIRFILTERDESIGNREPLY']._serialized_start=454
  _globals['_PYBRIDGEIIRFILTERDESIGNREPLY']._serialized_end=508
  _globals['_PYBRIDGEGETSPECREPLY']._serialized_start=511
  _globals['_PYBRIDGEGETSPECREPLY']._serialized_end=797
  _globals['_PYBRIDGETIMESPEC']._serialized_start=800
  _globals['_PYBRIDGETIMESPEC']._serialized_end=1272
  _globals['_PYBRIDGETIMESPEC_PYBRIDGETIMERANGET']._serialized_start=1027
  _globals['_PYBRIDGETIMESPEC_PYBRIDGETIMERANGET']._serialized_end=1066
  _globals['_PYBRIDGETIMESPEC_PYBRIDGETIMESTAMPRANGET']._serialized_start=1068
  _globals['_PYBRIDGETIMESPEC_PYBRIDGETIMESTAMPRANGET']._serialized_end=1117
  _globals['_PYBRIDGETIMESPEC_PYBRIDGEDATABLOCKRANGET']._serialized_start=1120
  _globals['_PYBRIDGETIMESPEC_PYBRIDGEDATABLOCKRANGET']._serialized_end=1272
  _globals['_PYBRIDGEPORTMAP']._serialized_start=1275
  _globals['_PYBRIDGEPORTMAP']._serialized_end=1704
  _globals['_PYBRIDGEPORTMAP_PYBRIDGESITEPOS']._serialized_start=1511
  _globals['_PYBRIDGEPORTMAP_PYBRIDGESITEPOS']._serialized_end=1544
  _globals['_PYBRIDGEPORTMAP_PORTIDXTODFSIGMAPENTRY']._serialized_start=1546
  _globals['_PYBRIDGEPORTMAP_PORTIDXTODFSIGMAPENTRY']._serialized_end=1602
  _globals['_PYBRIDGEPORTMAP_DFCHANIDXTODFSITEPOSENTRY']._serialized_start=1604
  _globals['_PYBRIDGEPORTMAP_DFCHANIDXTODFSITEPOSENTRY']._serialized_end=1704
  _globals['_PYBRIDGEFILEMETADATA']._serialized_start=1707
  _globals['_PYBRIDGEFILEMETADATA']._serialized_end=2260
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS']._serialized_start=1914
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS']._serialized_end=2076
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS_PORTMAPENTRY']._serialized_start=2005
  _globals['_PYBRIDGEFILEMETADATA_PYBRIDGEPORTS_PORTMAPENTRY']._serialized_end=2076
  _globals['_PYBRIDGEFILEMETADATA_METADATARHD']._serialized_start=2079
  _globals['_PYBRIDGEFILEMETADATA_METADATARHD']._serialized_end=2260
  _globals['_PYBRIDGEGETSTATUSREPLY']._serialized_start=2262
  _globals['_PYBRIDGEGETSTATUSREPLY']._serialized_end=2310
  _globals['_PYBRIDGEGETSIGNALSREQUEST']._serialized_start=2312
  _globals['_PYBRIDGEGETSIGNALSREQUEST']._serialized_end=2421
  _globals['_PYBRIDGEGETSIGNALSREPLY']._serialized_start=2424
  _globals['_PYBRIDGEGETSIGNALSREPLY']._serialized_end=2655
  _globals['_MEARECSIGNALREQUEST']._serialized_start=2657
  _globals['_MEARECSIGNALREQUEST']._serialized_end=2702
  _globals['_MEARECSIGNALREPLY']._serialized_start=2704
  _globals['_MEARECSIGNALREPLY']._serialized_end=2752
  _globals['_MEARECTEMPLATEREQUEST']._serialized_start=2754
  _globals['_MEARECTEMPLATEREQUEST']._serialized_end=2798
  _globals['_MEARECWAVEFORMREQUEST']._serialized_start=2800
  _globals['_MEARECWAVEFORMREQUEST']._serialized_end=2845
  _globals['_SPIKESPUSHTOEXPORTREQ']._serialized_start=2848
  _globals['_SPIKESPUSHTOEXPORTREQ']._serialized_end=3160
  _globals['_SPIKESEXPORTMETADATA']._serialized_start=3163
  _globals['_SPIKESEXPORTMETADATA']._serialized_end=3323
  _globals['_MEARECWAVEFORMSTREAMREQUEST']._serialized_start=3325
  _globals['_MEARECWAVEFORMSTREAMREQUEST']._serialized_end=3398
  _globals['_MEARECFILEMETA']._serialized_start=3401
  _globals['_MEARECFILEMETA']._serialized_end=3671
  _globals['_MEARECWAVEFORMCHUNK']._serialized_start=3673
  _globals['_MEARECWAVEFORMCHUNK']._serialized_end=3774
  _globals['_MEARECTEMPLATE']._serialized_start=3776
  _globals['_MEARECTEMPLATE']._serialized_end=3847
  _globals['_MEARECWAVEFORM']._serialized_start=3849
  _globals['_MEARECWAVEFORM']._serialized_end=3939
  _globals['_PYBRIDGE']._serialized_start=4124
  _globals['_PYBRIDGE']._serialized_end=5435
# @@protoc_insertion_point(module_scope)
