"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
from . import common_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RadiensDatasourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RadiensDatasourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RadiensDatasourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ANY: _RadiensDatasourceType.ValueType  # 0
    TIMESERIES: _RadiensDatasourceType.ValueType  # 1

class RadiensDatasourceType(_RadiensDatasourceType, metaclass=_RadiensDatasourceTypeEnumTypeWrapper):
    """used by sapiensserver client"""

ANY: RadiensDatasourceType.ValueType  # 0
TIMESERIES: RadiensDatasourceType.ValueType  # 1
global___RadiensDatasourceType = RadiensDatasourceType

@typing.final
class DataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DSOURCEID_FIELD_NUMBER: builtins.int
    RENAMEDSRCID_FIELD_NUMBER: builtins.int
    renameDsrcID: builtins.str
    @property
    def dsourceID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dsourceID: collections.abc.Iterable[builtins.str] | None = ...,
        renameDsrcID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["renameDsrcID", b"renameDsrcID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dsourceID", b"dsourceID", "renameDsrcID", b"renameDsrcID"]) -> None: ...

global___DataSourceRequest = DataSourceRequest

@typing.final
class DataSourceSetSaveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    BASENAME_FIELD_NUMBER: builtins.int
    DSOURCEID_FIELD_NUMBER: builtins.int
    FILETYPE_FIELD_NUMBER: builtins.int
    ISFORCE_FIELD_NUMBER: builtins.int
    ISBACKGROUNDKPI_FIELD_NUMBER: builtins.int
    PARENTDSOURCEID_FIELD_NUMBER: builtins.int
    ALLOWGPIOONLYXDAT_FIELD_NUMBER: builtins.int
    FINDASSOCIATED_FIELD_NUMBER: builtins.int
    path: builtins.str
    baseName: builtins.str
    dsourceID: builtins.str
    """datasource manager data source ID"""
    fileType: common_pb2.RadixFileTypes.ValueType
    """optional string uID = 4;  // deprecated"""
    isForce: builtins.bool
    isBackgroundKPI: builtins.bool
    parentDsourceID: builtins.str
    allowGPIOOnlyXDAT: builtins.bool
    """optional bool forceNoSorter = 9; // deprecated
    if allowGPIOOnlyXDAT is set, then an XDAT file with only GPIO data can be opened/registered. 
    This option was created for use with Curate to slice GPIO channels from the XDAT sidecar that gets saved alongside the spikes in spikes-only mode
    If allowGPIOOnlyXDAT is no set or false, then XDAT files with no AMP channels are considered proxies for their associated spikes files,
    which will be opened instead.
    """
    findAssociated: builtins.bool
    """if true, find and return associated datasources as well"""
    def __init__(
        self,
        *,
        path: builtins.str | None = ...,
        baseName: builtins.str | None = ...,
        dsourceID: builtins.str | None = ...,
        fileType: common_pb2.RadixFileTypes.ValueType | None = ...,
        isForce: builtins.bool | None = ...,
        isBackgroundKPI: builtins.bool | None = ...,
        parentDsourceID: builtins.str | None = ...,
        allowGPIOOnlyXDAT: builtins.bool | None = ...,
        findAssociated: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allowGPIOOnlyXDAT", b"allowGPIOOnlyXDAT", "baseName", b"baseName", "dsourceID", b"dsourceID", "fileType", b"fileType", "findAssociated", b"findAssociated", "isBackgroundKPI", b"isBackgroundKPI", "isForce", b"isForce", "parentDsourceID", b"parentDsourceID", "path", b"path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowGPIOOnlyXDAT", b"allowGPIOOnlyXDAT", "baseName", b"baseName", "dsourceID", b"dsourceID", "fileType", b"fileType", "findAssociated", b"findAssociated", "isBackgroundKPI", b"isBackgroundKPI", "isForce", b"isForce", "parentDsourceID", b"parentDsourceID", "path", b"path"]) -> None: ...

global___DataSourceSetSaveRequest = DataSourceSetSaveRequest

@typing.final
class DataSourceIDReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORTEDID_FIELD_NUMBER: builtins.int
    @property
    def sortedID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        sortedID: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sortedID", b"sortedID"]) -> None: ...

global___DataSourceIDReply = DataSourceIDReply

@typing.final
class FileDescriptors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[common_pb2.FileDescriptor]: ...
    def __init__(
        self,
        *,
        desc: collections.abc.Iterable[common_pb2.FileDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desc", b"desc"]) -> None: ...

global___FileDescriptors = FileDescriptors

@typing.final
class DataSourceSetSaveReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DSOURCEID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ASSOCIATEDDSRCS_FIELD_NUMBER: builtins.int
    dsourceID: builtins.str
    """datasource manager data source ID"""
    @property
    def status(self) -> common_pb2.DataSourceStatus: ...
    @property
    def associatedDsrcs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[common_pb2.FileDescriptor]: ...
    def __init__(
        self,
        *,
        dsourceID: builtins.str | None = ...,
        status: common_pb2.DataSourceStatus | None = ...,
        associatedDsrcs: collections.abc.Iterable[common_pb2.FileDescriptor] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dsourceID", b"dsourceID", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["associatedDsrcs", b"associatedDsrcs", "dsourceID", b"dsourceID", "status", b"status"]) -> None: ...

global___DataSourceSetSaveReply = DataSourceSetSaveReply

@typing.final
class DataSourceStatusMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DsourceEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> common_pb2.DataSourceStatus: ...
        def __init__(
            self,
            *,
            key: builtins.str | None = ...,
            value: common_pb2.DataSourceStatus | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DSOURCE_FIELD_NUMBER: builtins.int
    ORDEREDIDS_FIELD_NUMBER: builtins.int
    @property
    def dsource(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, common_pb2.DataSourceStatus]:
        """key: datasource ID"""

    @property
    def orderedIDs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dsource: collections.abc.Mapping[builtins.str, common_pb2.DataSourceStatus] | None = ...,
        orderedIDs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dsource", b"dsource", "orderedIDs", b"orderedIDs"]) -> None: ...

global___DataSourceStatusMap = DataSourceStatusMap

@typing.final
class CopyRemoveDataSourceFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MultipleFiles(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SRC_FIELD_NUMBER: builtins.int
        DESTPATH_FIELD_NUMBER: builtins.int
        DESTFILETYPE_FIELD_NUMBER: builtins.int
        destPath: builtins.str
        destFileType: common_pb2.RadixFileTypes.ValueType
        @property
        def src(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[common_pb2.FileDescriptor]: ...
        def __init__(
            self,
            *,
            src: collections.abc.Iterable[common_pb2.FileDescriptor] | None = ...,
            destPath: builtins.str | None = ...,
            destFileType: common_pb2.RadixFileTypes.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["destFileType", b"destFileType", "destPath", b"destPath"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["destFileType", b"destFileType", "destPath", b"destPath", "src", b"src"]) -> None: ...

    @typing.final
    class OneFile(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SRC_FIELD_NUMBER: builtins.int
        DEST_FIELD_NUMBER: builtins.int
        @property
        def src(self) -> common_pb2.FileDescriptor: ...
        @property
        def dest(self) -> common_pb2.FileDescriptor: ...
        def __init__(
            self,
            *,
            src: common_pb2.FileDescriptor | None = ...,
            dest: common_pb2.FileDescriptor | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["dest", b"dest", "src", b"src"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["dest", b"dest", "src", b"src"]) -> None: ...

    MANY_FIELD_NUMBER: builtins.int
    ONE_FIELD_NUMBER: builtins.int
    ISFORCE_FIELD_NUMBER: builtins.int
    ISVALIDATE_FIELD_NUMBER: builtins.int
    isForce: builtins.bool
    isValidate: builtins.bool
    @property
    def many(self) -> global___CopyRemoveDataSourceFileRequest.MultipleFiles: ...
    @property
    def one(self) -> global___CopyRemoveDataSourceFileRequest.OneFile: ...
    def __init__(
        self,
        *,
        many: global___CopyRemoveDataSourceFileRequest.MultipleFiles | None = ...,
        one: global___CopyRemoveDataSourceFileRequest.OneFile | None = ...,
        isForce: builtins.bool | None = ...,
        isValidate: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["desc", b"desc", "isForce", b"isForce", "isValidate", b"isValidate", "many", b"many", "one", b"one"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desc", b"desc", "isForce", b"isForce", "isValidate", b"isValidate", "many", b"many", "one", b"one"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["desc", b"desc"]) -> typing.Literal["many", "one"] | None: ...

global___CopyRemoveDataSourceFileRequest = CopyRemoveDataSourceFileRequest

@typing.final
class DataSourceFileSetStat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMFILES_FIELD_NUMBER: builtins.int
    NUMBYTESPRIMARYDATA_FIELD_NUMBER: builtins.int
    NUMBYTESMETADATA_FIELD_NUMBER: builtins.int
    NUMBYTES_FIELD_NUMBER: builtins.int
    ISMETADATAFILE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    NUMCHANNELS_FIELD_NUMBER: builtins.int
    DURATIONSEC_FIELD_NUMBER: builtins.int
    DATASETUID_FIELD_NUMBER: builtins.int
    DATASETCHECKSUM_FIELD_NUMBER: builtins.int
    DATASETPROVENANCE_FIELD_NUMBER: builtins.int
    SAMPLERATE_FIELD_NUMBER: builtins.int
    BACKGROUNDPROC_FIELD_NUMBER: builtins.int
    numFiles: builtins.int
    numBytesPrimaryData: builtins.int
    numBytesMetaData: builtins.int
    numBytes: builtins.int
    isMetadataFile: builtins.bool
    numChannels: builtins.int
    durationSec: builtins.float
    datasetUID: builtins.str
    datasetChecksum: builtins.str
    sampleRate: builtins.int
    @property
    def timeStamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def datasetProvenance(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def backgroundProc(self) -> global___BackgroundProcessStatus: ...
    def __init__(
        self,
        *,
        numFiles: builtins.int | None = ...,
        numBytesPrimaryData: builtins.int | None = ...,
        numBytesMetaData: builtins.int | None = ...,
        numBytes: builtins.int | None = ...,
        isMetadataFile: builtins.bool | None = ...,
        timeStamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        numChannels: builtins.int | None = ...,
        durationSec: builtins.float | None = ...,
        datasetUID: builtins.str | None = ...,
        datasetChecksum: builtins.str | None = ...,
        datasetProvenance: collections.abc.Iterable[builtins.str] | None = ...,
        sampleRate: builtins.int | None = ...,
        backgroundProc: global___BackgroundProcessStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backgroundProc", b"backgroundProc", "datasetChecksum", b"datasetChecksum", "datasetUID", b"datasetUID", "durationSec", b"durationSec", "isMetadataFile", b"isMetadataFile", "numBytes", b"numBytes", "numBytesMetaData", b"numBytesMetaData", "numBytesPrimaryData", b"numBytesPrimaryData", "numChannels", b"numChannels", "numFiles", b"numFiles", "sampleRate", b"sampleRate", "timeStamp", b"timeStamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backgroundProc", b"backgroundProc", "datasetChecksum", b"datasetChecksum", "datasetProvenance", b"datasetProvenance", "datasetUID", b"datasetUID", "durationSec", b"durationSec", "isMetadataFile", b"isMetadataFile", "numBytes", b"numBytes", "numBytesMetaData", b"numBytesMetaData", "numBytesPrimaryData", b"numBytesPrimaryData", "numChannels", b"numChannels", "numFiles", b"numFiles", "sampleRate", b"sampleRate", "timeStamp", b"timeStamp"]) -> None: ...

global___DataSourceFileSetStat = DataSourceFileSetStat

@typing.final
class CpRmMvLsReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DataSourceInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DESC_FIELD_NUMBER: builtins.int
        STAT_FIELD_NUMBER: builtins.int
        @property
        def desc(self) -> common_pb2.FileDescriptor: ...
        @property
        def stat(self) -> global___DataSourceFileSetStat: ...
        def __init__(
            self,
            *,
            desc: common_pb2.FileDescriptor | None = ...,
            stat: global___DataSourceFileSetStat | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["desc", b"desc", "stat", b"stat"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["desc", b"desc", "stat", b"stat"]) -> None: ...

    NUMFILES_FIELD_NUMBER: builtins.int
    NUMDSOURCE_FIELD_NUMBER: builtins.int
    NUMBYTES_FIELD_NUMBER: builtins.int
    DESTPATH_FIELD_NUMBER: builtins.int
    DSOURCE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    numFiles: builtins.int
    numDsource: builtins.int
    numBytes: builtins.int
    destPath: builtins.str
    msg: builtins.str
    @property
    def dsource(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CpRmMvLsReply.DataSourceInfo]: ...
    def __init__(
        self,
        *,
        numFiles: builtins.int | None = ...,
        numDsource: builtins.int | None = ...,
        numBytes: builtins.int | None = ...,
        destPath: builtins.str | None = ...,
        dsource: collections.abc.Iterable[global___CpRmMvLsReply.DataSourceInfo] | None = ...,
        msg: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destPath", b"destPath", "msg", b"msg", "numBytes", b"numBytes", "numDsource", b"numDsource", "numFiles", b"numFiles"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destPath", b"destPath", "dsource", b"dsource", "msg", b"msg", "numBytes", b"numBytes", "numDsource", b"numDsource", "numFiles", b"numFiles"]) -> None: ...

global___CpRmMvLsReply = CpRmMvLsReply

@typing.final
class BackgroundProcessStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    FRACCOMPLETE_FIELD_NUMBER: builtins.int
    ELAPSEDTIMESEC_FIELD_NUMBER: builtins.int
    ESTIMATEDCOMPLETIONWALLTIME_FIELD_NUMBER: builtins.int
    uID: builtins.str
    fracComplete: builtins.float
    elapsedTimeSec: builtins.float
    estimatedCompletionWallTime: builtins.str
    def __init__(
        self,
        *,
        uID: builtins.str | None = ...,
        fracComplete: builtins.float | None = ...,
        elapsedTimeSec: builtins.float | None = ...,
        estimatedCompletionWallTime: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["elapsedTimeSec", b"elapsedTimeSec", "estimatedCompletionWallTime", b"estimatedCompletionWallTime", "fracComplete", b"fracComplete", "uID", b"uID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["elapsedTimeSec", b"elapsedTimeSec", "estimatedCompletionWallTime", b"estimatedCompletionWallTime", "fracComplete", b"fracComplete", "uID", b"uID"]) -> None: ...

global___BackgroundProcessStatus = BackgroundProcessStatus

@typing.final
class MoveDataSourceFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_FIELD_NUMBER: builtins.int
    DEST_FIELD_NUMBER: builtins.int
    ISFORCE_FIELD_NUMBER: builtins.int
    ISVALIDATE_FIELD_NUMBER: builtins.int
    isForce: builtins.bool
    isValidate: builtins.bool
    @property
    def src(self) -> common_pb2.FileDescriptor: ...
    @property
    def dest(self) -> common_pb2.FileDescriptor: ...
    def __init__(
        self,
        *,
        src: common_pb2.FileDescriptor | None = ...,
        dest: common_pb2.FileDescriptor | None = ...,
        isForce: builtins.bool | None = ...,
        isValidate: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dest", b"dest", "isForce", b"isForce", "isValidate", b"isValidate", "src", b"src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dest", b"dest", "isForce", b"isForce", "isValidate", b"isValidate", "src", b"src"]) -> None: ...

global___MoveDataSourceFileRequest = MoveDataSourceFileRequest

@typing.final
class ExportDataSourceFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_FIELD_NUMBER: builtins.int
    DEST_FIELD_NUMBER: builtins.int
    ISFORCE_FIELD_NUMBER: builtins.int
    isForce: builtins.bool
    @property
    def src(self) -> common_pb2.FileDescriptor: ...
    @property
    def dest(self) -> common_pb2.FileDescriptor: ...
    def __init__(
        self,
        *,
        src: common_pb2.FileDescriptor | None = ...,
        dest: common_pb2.FileDescriptor | None = ...,
        isForce: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dest", b"dest", "isForce", b"isForce", "src", b"src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dest", b"dest", "isForce", b"isForce", "src", b"src"]) -> None: ...

global___ExportDataSourceFileRequest = ExportDataSourceFileRequest

@typing.final
class DataSourceParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAMPLEFREQ_FIELD_NUMBER: builtins.int
    TIMERANGE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DATASOURCETYPE_FIELD_NUMBER: builtins.int
    DATASOURCEID_FIELD_NUMBER: builtins.int
    sampleFreq: builtins.float
    duration: builtins.float
    type: common_pb2.SignalGroupType.ValueType
    datasourceType: global___RadiensDatasourceType.ValueType
    """used by sapiensserver client"""
    datasourceID: builtins.str
    """used by sapiensserver client"""
    @property
    def timeRange(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        sampleFreq: builtins.float | None = ...,
        timeRange: collections.abc.Iterable[builtins.float] | None = ...,
        duration: builtins.float | None = ...,
        type: common_pb2.SignalGroupType.ValueType | None = ...,
        datasourceType: global___RadiensDatasourceType.ValueType | None = ...,
        datasourceID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["datasourceID", b"datasourceID", "datasourceType", b"datasourceType", "duration", b"duration", "sampleFreq", b"sampleFreq", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["datasourceID", b"datasourceID", "datasourceType", b"datasourceType", "duration", b"duration", "sampleFreq", b"sampleFreq", "timeRange", b"timeRange", "type", b"type"]) -> None: ...

global___DataSourceParams = DataSourceParams

@typing.final
class ImpedanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    port: common_pb2.Port.ValueType
    def __init__(
        self,
        *,
        port: common_pb2.Port.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["port", b"port"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["port", b"port"]) -> None: ...

global___ImpedanceRequest = ImpedanceRequest

@typing.final
class Impedance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ImpedanceValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NTVCHANIDX_FIELD_NUMBER: builtins.int
        ZMAG_FIELD_NUMBER: builtins.int
        ZPHASE_FIELD_NUMBER: builtins.int
        ntvChanIdx: builtins.int
        zMag: builtins.float
        zPhase: builtins.float
        def __init__(
            self,
            *,
            ntvChanIdx: builtins.int | None = ...,
            zMag: builtins.float | None = ...,
            zPhase: builtins.float | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ntvChanIdx", b"ntvChanIdx", "zMag", b"zMag", "zPhase", b"zPhase"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ntvChanIdx", b"ntvChanIdx", "zMag", b"zMag", "zPhase", b"zPhase"]) -> None: ...

    IMPEDANCES_FIELD_NUMBER: builtins.int
    @property
    def impedances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Impedance.ImpedanceValue]: ...
    def __init__(
        self,
        *,
        impedances: collections.abc.Iterable[global___Impedance.ImpedanceValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["impedances", b"impedances"]) -> None: ...

global___Impedance = Impedance
